var INFO_PERCENTILES, INFO_FETAL, INFO_ZSCORE, ABBREV_FETAL;
var INFO_LEE = "Lee et al. 2010";

function setStrings() {
	INFO_PERCENTILES = window.lang.convert("Percentiles according to") + ":<br>";
	INFO_FETAL = '<a href="http://www.ncbi.nlm.nih.gov/pubmed/20014329" target=_blank>Lee et al. 2010</a>';
	INFO_ZSCORE = window.lang.convert("The diagram represents following interval") + ": -2z, 0z, +2z";
	ABBREV_FETAL = window.lang.convert("Aortic valve and pulmonary valve in endsystole; Cardiac circumference in enddiastole");

}

function fetal_calc() {

	var aov = $('#fetal_aov').val().replace(/,/, ".") * 1;
	var pv = $('#fetal_pv').val().replace(/,/, ".") * 1;
	var lvedd = $('#fetal_lvedd').val().replace(/,/, ".") * 1;
	var rvedd = $('#fetal_rvedd').val().replace(/,/, ".") * 1;
	var cc = $('#fetal_cc').val().replace(/,/, ".") * 1;
	var references = new Array();
	var diaphysis = $('#fetal_diaphysis').val().replace(/,/, ".") * 1;
	var menstrual = $('#fetal_menstrual').val().replace(/,/, ".") * 1;
	var biparietal = $('#fetal_biparietal').val().replace(/,/, ".") * 1;
	var corValue;
	var correlation = $('#fetalSelect').val();
	var obAov, obPv, obLvedd, obRvedd,obCc;
	// Erase old results
	$("* .zs-arrow-left").css("visibility", "hidden");
	$("* .zs-arrow-right").css("visibility", "hidden");
	$("* .zs-result-marker").css("visibility", "hidden");
	$("div[id$='lln']").html("");
	$("div[id$='uln']").html("");
	$("div[id$='mean']").html("");
	
	switch (correlation) {
		case "diaphysis":
		corValue = diaphysis;
		break;
			case "menstrual":
		corValue = menstrual;
		break;
			case "biparietal":
		corValue = biparietal;
		break;
		default:
		break;
	}
		
	
	obAov= new FetalAov(aov, corValue,correlation);
	obPv= new FetalPv(pv, corValue,correlation);
	obLvedd= new FetalLvedd(lvedd, corValue,correlation);
	obRvedd= new FetalRvedd(rvedd, corValue,correlation);
	obCc= new FetalCc(cc, corValue,correlation);
	
	$('#infoAov').html(obAov.infoString);
	$('#infoPv').html(obPv.infoString);
	$('#infoLvedd').html(obLvedd.infoString);
	$('#infoRvedd').html(obRvedd.infoString);
	$('#infoCc').html(obCc.infoString);
		
	$('#fetal_aov_lln').html(obAov.getValueFromZ(-2).toFixed(1));
	$('#fetal_aov_mean').html(obAov.getValueFromZ(0).toFixed(1));
	$('#fetal_aov_uln').html(obAov.getValueFromZ(2).toFixed(1));
	$('#fetal_pv_lln').html(obPv.getValueFromZ(-2).toFixed(1));
	$('#fetal_pv_mean').html(obPv.getValueFromZ(0).toFixed(1));
	$('#fetal_pv_uln').html(obPv.getValueFromZ(2).toFixed(1));
	$('#fetal_lvedd_lln').html(obLvedd.getValueFromZ(-2).toFixed(1));
	$('#fetal_lvedd_mean').html(obLvedd.getValueFromZ(0).toFixed(1));
	$('#fetal_lvedd_uln').html(obLvedd.getValueFromZ(2).toFixed(1));
	$('#fetal_rvedd_lln').html(obRvedd.getValueFromZ(-2).toFixed(1));
	$('#fetal_rvedd_mean').html(obRvedd.getValueFromZ(0).toFixed(1));
	$('#fetal_rvedd_uln').html(obRvedd.getValueFromZ(2).toFixed(1));
	$('#fetal_cc_lln').html(obCc.getValueFromZ(-2).toFixed(1));
	$('#fetal_cc_mean').html(obCc.getValueFromZ(0).toFixed(1));
	$('#fetal_cc_uln').html(obCc.getValueFromZ(2).toFixed(1));


	// Erasing uln,mean,lln returned with errorcode -100
	$("div[id$='lln']").each(function(index) {
		if ($(this).html() === "-100.0") $(this).html("")
	});
	$("div[id$='uln']").each(function(index) {
		if ($(this).html() === "-100.0") $(this).html("")
	});
	$("div[id$='mean']").each(function(index) {
		if ($(this).html() === "-100.0") $(this).html("")
	});

references = obAov.showResults(references);
references = obPv.showResults(references);
references = obLvedd.showResults(references);
references = obRvedd.showResults(references);
references = obCc.showResults(references);
}

function FetalAov(value, corValue, correlation) {
	this.corValue = corValue || -1;
	this.correlation = correlation || "";
	this.value = value || -1;
	this.refString = INFO_LEE;
	this.init();
	this.infoString = this.getInfo([INFO_PERCENTILES + INFO_FETAL, INFO_ZSCORE, ABBREV_FETAL]);
	this.paramName = "aov";
	this.paramNameLong = "AoV";
	this.paramUnit = "mm";
	this.mean = undefined;
	this.sd = undefined;
	
	this.getUpperAndLowerValues = function() {
		if (this.corValue > 0) {
		switch (correlation) {
	case "diaphysis":
	this.mean = 0.288 * this.corValue - 2.59;
	this.sd = 0.0054 * this.corValue + 0.239;
			break;
			case "menstrual":
			this.mean = 0.288 * this.corValue - 2.59;
			this.sd = 0.0165 * this.corValue + 0.064;
			break;
			case "biparietal":
			this.mean = 0.099 * this.corValue - 1.49;
			this.sd = 0.0063 * this.corValue + 0.111;
			break;
			default:
			break;
	}
		}
	}	
		// Checking specific errors and creating error messages	
	this.errorCondition.push(corValue <= 0)
	this.errorString.push(window.lang.convert("Either femur diaphysis, menstrual age or biparietal diameter is needed"));
	this.errorCondition.push(value <= 0)
	this.errorString.push(window.lang.convert("Weight") + " " + window.lang.convert("has to be greater than 0"));
	this.getUpperAndLowerValues();
}
FetalAov.prototype = new MeanSdClass();

function FetalPv(value, corValue, correlation) {
	this.corValue = corValue || -1;
	this.correlation = correlation || "";
	this.value = value || -1;
	this.refString = INFO_LEE;
	this.init();
	this.infoString = this.getInfo([INFO_PERCENTILES + INFO_FETAL, INFO_ZSCORE, ABBREV_FETAL]);
	this.paramName = "pv";
	this.paramNameLong = "PV";
	this.paramUnit = "mm";
	this.mean = undefined;
	this.sd = undefined;
	
	this.getUpperAndLowerValues = function() {
		if (this.corValue > 0) {
		switch (correlation) {
	case "diaphysis":
			this.mean = 0.312 * this.corValue - 2.73;
			this.sd = 0.0103 * this.corValue + 0.150;
			break;
			case "menstrual":
			this.mean = 0.312 * this.corValue - 2.73;
			this.sd = 0.0253 * this.corValue - 0.048
			break;
			case "biparietal":
			this.mean = 0.108 * this.corValue - 1.56;
			this.sd = 0.0091 * this.corValue - 0.0338;
			break;
			default:
			break;
	}
		}
	}	
		this.errorCondition.push(corValue <= 0)
	this.errorString.push(window.lang.convert("Either femur diaphysis, menstrual age or biparietal diameter is needed"));
	this.errorCondition.push(value <= 0)
	this.errorString.push(window.lang.convert("Weight") + " " + window.lang.convert("has to be greater than 0"));
	this.getUpperAndLowerValues();
}
FetalPv.prototype = new MeanSdClass();

function FetalLvedd(value, corValue, correlation) {
	this.corValue = corValue || -1;
	this.correlation = correlation || "";
	this.value = value || -1;
	this.refString = INFO_LEE;
	this.init();
	this.infoString = this.getInfo([INFO_PERCENTILES + INFO_FETAL, INFO_ZSCORE, ABBREV_FETAL]);
	this.paramName = "lvedd";
	this.paramNameLong = "LVEDD";
	this.paramUnit = "mm";
	this.mean = undefined;
	this.sd = undefined;
	
	this.getUpperAndLowerValues = function() {
		if (this.corValue > 0) {
		switch (correlation) {
	case "diaphysis":
			this.mean = 0.513 * this.corValue - 3.81;
			this.sd = 0.0135 * this.corValue + 0.395;
			break;
			case "menstrual":
			this.mean = 0.513 * this.corValue - 3.81;
			this.sd = 0.0394 * this.corValue + 0.059;
			break;
			case "biparietal":
			this.mean = 0.178 * this.corValue - 1.92;
			this.sd = 0.0125 * this.corValue + 0.248;
			break;
			default:
			break;
	}
		}
	}	
		this.errorCondition.push(corValue <= 0)
	this.errorString.push(window.lang.convert("Either femur diaphysis, menstrual age or biparietal diameter is needed"));
	this.errorCondition.push(value <= 0)
	this.errorString.push(window.lang.convert("Weight") + " " + window.lang.convert("has to be greater than 0"));
this.getUpperAndLowerValues();
}
FetalLvedd.prototype = new MeanSdClass();

function FetalRvedd(value, corValue, correlation) {
	this.corValue = corValue || -1;
	this.correlation = correlation || "";
	this.value = value || -1;
	this.refString = INFO_LEE;
	this.init();
	this.infoString = this.getInfo([INFO_PERCENTILES + INFO_FETAL, INFO_ZSCORE, ABBREV_FETAL]);
	this.paramName = "rvedd";
	this.paramNameLong = "RVEDD";
	this.paramUnit = "mm";
	this.mean = undefined;
	this.sd = undefined;
	
	this.getUpperAndLowerValues = function() {
		if (this.corValue > 0) {
		switch (correlation) {
	case "diaphysis":
			this.mean = 0.541 * this.corValue - 4.35;
			this.sd = 0.0138 * this.corValue + 0.466;
			break;
			case "menstrual":
			this.mean = 0.541 * this.corValue - 4.35;
			this.sd = 0.0394 * this.corValue + 0.132;
			break;
			case "biparietal":
			this.mean = 0.188 * this.corValue - 2.37;
			this.sd = 0.0147 * this.corValue + 0.198;
			break;
			default:
			break;
	}
		}
	}	

		this.errorCondition.push(corValue <= 0)
	this.errorString.push(window.lang.convert("Either femur diaphysis, menstrual age or biparietal diameter is needed"));
	this.errorCondition.push(value <= 0)
	this.errorString.push(window.lang.convert("Weight") + " " + window.lang.convert("has to be greater than 0"));
this.getUpperAndLowerValues();
}
FetalRvedd.prototype = new MeanSdClass();

function FetalCc(value, corValue, correlation) {
	this.corValue = corValue || -1;
	this.correlation = correlation || "";
	this.value = value || -1;
	this.refString = INFO_LEE;
	this.init();
	this.infoString = this.getInfo([INFO_PERCENTILES + INFO_FETAL, INFO_ZSCORE, ABBREV_FETAL]);
	this.paramName = "cc";
	this.paramNameLong = "Cardiac circumference";
	this.paramUnit = "mm";
	this.mean = undefined;
	this.sd = undefined;
	
	this.getUpperAndLowerValues = function() {
		if (this.corValue > 0) {
		switch (correlation) {
	case "diaphysis":
			this.mean = 4.88 * this.corValue - 32.9;
			this.sd = 0.145 * this.corValue + 0.700;
			break;
			case "menstrual":
			this.mean = 4.88 * this.corValue - 32.9;
			this.sd = 0.341 * this.corValue - 1.456;
			break;
			case "biparietal":
			this.mean = 1.69 * this.corValue - 15.0;
			this.sd = 0.118 * this.corValue - 0.178;
			break;
			default:
			break;
	}
		}
	}	

	
this.errorCondition.push(corValue <= 0)
	this.errorString.push(window.lang.convert("Either femur diaphysis, menstrual age or biparietal diameter is needed"));
	this.errorCondition.push(value <= 0)
	this.errorString.push(window.lang.convert("Weight") + " " + window.lang.convert("has to be greater than 0"));
this.getUpperAndLowerValues();
}
FetalCc.prototype = new MeanSdClass();


