var INFO_GROTHOFF, INFO_ZSCORE
var REF_GROTHOFF = "Grothoff et al. 2015";
var ABBREV_GROTHOFF = "STJ: Sinotubular junction";

function setStrings() {
	INFO_GROTHOFF = window.lang.convert("Z-Scores for aortic dimensions in patients with corrected TOF") + ", " + '<a href="http://www.ncbi.nlm.nih.gov/pubmed/25928314">Links folgt</a>';
	INFO_ZSCORE = window.lang.convert("The diagram represents following interval") + ": -2z, 0z, +2z";
	}

function tof_calc() {
	var height = $('#height').val().replace(',', ".") * 1;
	var weight = $('#weight').val().replace(',', ".") * 1;

	var annulus = $('#Annulus').val().replace(/,/, ".") * 1;
	var sinus = $('#Sinus').val().replace(/,/, ".") * 1;
	var stj = $('#Stj').val().replace(/,/, ".") * 1;
	var ascendens = $('#Ascendens').val().replace(/,/, ".") * 1;
	 
	
	

	var weight,height,bsa,outputTemp,bmi,obAnnulus,obSinus,obStj,obAscendens;
	if ($("input[name='radio']:checked").val() == "male") male = true;
	else male = false;

	// Erase old results
	$("* .zs-arrow-left").css("visibility", "hidden");
	$("* .zs-arrow-right").css("visibility", "hidden");
	$("* .zs-result-marker").css("visibility", "hidden");

	$("div[id$='lln']").html("");
	$("div[id$='uln']").html("");
	$("div[id$='mean']").html("");

	references = new Array();
	outputTemp = "";


	// Calculate BSA 
	if ((weight > 0) && (height > 0)) {
		bsa = bsaDuBois(height, weight);
		bmi = weight / Math.pow(height/100,2);
		$('#bsa_result').html(bsa.toFixed(2) + " m²");
	}
	else bsa = 0;
	
	
	//  Aorta
	references = new Array();
	
	obAnnulus = new grothoffAnnulus(annulus, weight,height,male);
	$('#infoAnnulus').html(obAnnulus.infoString);
	$('#Annulus_lln').html(obAnnulus.getValueFromZ(-2).toFixed(0));
	$('#Annulus_mean').html(obAnnulus.getValueFromZ(0).toFixed(0));
	$('#Annulus_uln').html(obAnnulus.getValueFromZ(2).toFixed(0));
	references = obAnnulus.showResults(references);
	
	obSinus = new grothoffSinus(sinus,  weight,height,male);
	$('#infoSinus').html(obSinus.infoString);
	$('#Sinus_lln').html(obSinus.getValueFromZ(-2).toFixed(0));
	$('#Sinus_mean').html(obSinus.getValueFromZ(0).toFixed(0));
	$('#Sinus_uln').html(obSinus.getValueFromZ(2).toFixed(0));
	references = obSinus.showResults(references);
	
	obStj = new grothoffStj(stj, weight,height,male);
	$('#infoStj').html(obStj.infoString);
	$('#Stj_lln').html(obStj.getValueFromZ(-2).toFixed(0));
	$('#Stj_mean').html(obStj.getValueFromZ(0).toFixed(0));
	$('#Stj_uln').html(obStj.getValueFromZ(2).toFixed(0));
	references = obStj.showResults(references);
	
	obAscendens = new grothoffAscendens(ascendens, weight,height,male);
	$('#infoAscendens').html(obAscendens.infoString);
	$('#Ascendens_lln').html(obAscendens.getValueFromZ(-2).toFixed(0));
	$('#Ascendens_mean').html(obAscendens.getValueFromZ(0).toFixed(0));
	$('#Ascendens_uln').html(obAscendens.getValueFromZ(2).toFixed(0));
	references = obAscendens.showResults(references);
		 
	

if (references.length > 0) {
outputTemp += window.lang.convert("Aortic diameters, normal range for TOF patients in parentheses") + ": \n" + writeRefString(references) + "\n\n";
}
	$('#outputContent').html(outputTemp);

	// Erasing uln,mean,lln returned with errorcode -100
	$("div[id$='lln']").each(function(index) {
		if ($(this).html() === "-100") $(this).html("")
	});
	$("div[id$='uln']").each(function(index) {
		if ($(this).html() === "-100") $(this).html("")
	});
	$("div[id$='mean']").each(function(index) {
		if ($(this).html() === "-100") $(this).html("")
	});
}

function grothoffAnnulus(value, weight, height, male) {
	this.weight = weight || -1;
	this.height = height || -1;
	this.value = value || -1;
	this.hidePercentile = true;
	this.male = male;
	this.refString = REF_GROTHOFF;
	this.init();
	this.infoString = this.getInfo([INFO_GROTHOFF, INFO_ZSCORE]);
	this.paramName = "Annulus";
	this.paramNameLong = "Annulus";
	this.paramUnit = "mm";
	if (weight && height) this.bsa = bsaMosteller(this.height, this.weight);
	else this.bsa = -1;

	this.getValueFromZ = function(value) {
		if (this.bsa > 0) {
			if (this.male) return (3.6 + 16.6 * Math.pow(this.bsa, 0.5) + value*2.4);
			else return (5.8 + 14.1* Math.pow(this.bsa, 0.5) + value*2.3);
		} else return -100;
	}
	this.getZFromValue = function(value) {
		if ((this.bsa > 0) && (value > 0)) {
			if (this.male) return ((value - (3.6 + 16.6 * Math.pow(this.bsa, 0.5))) / 2.4); 
			else return ((value - (5.8 + 14.1* Math.pow(this.bsa, 0.5))) / 2.3); 
		} else return -100;
	}

	this.errorCondition.push((weight <= 0) || (height <= 0))
	this.errorString.push(window.lang.convert("Weight and height are needed"));
	this.errorCondition.push(value <= 0)
	this.errorString.push(window.lang.convert(this.paramNameLong) + " " + window.lang.convert("has to be greater than 0"));

}
grothoffAnnulus.prototype = new LMSClass();

function grothoffSinus(value, weight, height, male) {
	this.weight = weight || -1;
	this.height = height || -1;
	this.value = value || -1;
	this.hidePercentile = true;
	this.male = male;
	this.refString = REF_GROTHOFF;
	this.init();
	this.infoString = this.getInfo([INFO_GROTHOFF, INFO_ZSCORE]);
	this.paramName = "Sinus";
	this.paramNameLong = "Sinus";
	this.paramUnit = "mm";
	if (weight && height) this.bsa = bsaMosteller(this.height, this.weight);
	else this.bsa = -1;

	this.getValueFromZ = function(value) {
		if (this.bsa > 0) {
			if (this.male) return (7.0 + 19.5 * Math.pow(this.bsa, 0.5) + value*3.5);
			else return (7.2 + 17.6* Math.pow(this.bsa, 0.5) + value*3.2);
		} else return -100;
	}
	this.getZFromValue = function(value) {
		if ((this.bsa > 0) && (value > 0)) {
			if (this.male) return ((value - (7.0 + 19.5 * Math.pow(this.bsa, 0.5))) / 3.5); 
			else return ((value - (7.2 + 17.6* Math.pow(this.bsa, 0.5))) / 3.2); 
		} else return -100;
	}

	this.errorCondition.push((weight <= 0) || (height <= 0))
	this.errorString.push(window.lang.convert("Weight and height are needed"));
	this.errorCondition.push(value <= 0)
	this.errorString.push(window.lang.convert(this.paramNameLong) + " " + window.lang.convert("has to be greater than 0"));

}
grothoffSinus.prototype = new LMSClass();

function grothoffStj(value, weight, height, male) {
	this.weight = weight || -1;
	this.height = height || -1;
	this.value = value || -1;
	this.hidePercentile = true;
	this.male = male;
	this.refString = REF_GROTHOFF;
	this.init();
	this.infoString = this.getInfo([INFO_GROTHOFF, INFO_ZSCORE]);
	this.paramName = "Stj";
	this.paramNameLong = "STJ";
	this.paramUnit = "mm";
	if (weight && height) this.bsa = bsaMosteller(this.height, this.weight);
	else this.bsa = -1;

	this.getValueFromZ = function(value) {
		if (this.bsa > 0) {
			if (this.male) return (7.0 + 14.4 * Math.pow(this.bsa, 0.5) + value*4.3);
			else return (5.2 + 14.4 * Math.pow(this.bsa, 0.5) + value*3.5);
		} else return -100;
	}
	this.getZFromValue = function(value) {
		if ((this.bsa > 0) && (value > 0)) {
			if (this.male) return ((value - (7.0 + 14.4 * Math.pow(this.bsa, 0.5))) / 4.3); 
			else return ((value - (5.2 + 14.4 * Math.pow(this.bsa, 0.5))) / 3.5); 
		} else return -100;
	}

	this.errorCondition.push((weight <= 0) || (height <= 0))
	this.errorString.push(window.lang.convert("Weight and height are needed"));
	this.errorCondition.push(value <= 0)
	this.errorString.push(window.lang.convert(this.paramNameLong) + " " + window.lang.convert("has to be greater than 0"));

}
grothoffStj.prototype = new LMSClass();

function grothoffAscendens(value, weight, height, male) {
	this.weight = weight || -1;
	this.height = height || -1;
	this.value = value || -1;
	this.hidePercentile = true;
	this.male = male;
	this.refString = REF_GROTHOFF;
	this.init();
	this.infoString = this.getInfo([INFO_GROTHOFF, INFO_ZSCORE]);
	this.paramName = "Ascendens";
	this.paramNameLong = "Ascending aorta";
	this.paramUnit = "mm";
	if (weight && height) this.bsa = bsaMosteller(this.height, this.weight);
	else this.bsa = -1;

	this.getValueFromZ = function(value) {
		if (this.bsa > 0) {
			if (this.male) return (7.3 + 15.5 * Math.pow(this.bsa, 0.5) + value*4.0);
			else return (2.0 + 17.8* Math.pow(this.bsa, 0.5) + value*3.5);
		} else return -100;
	}
	this.getZFromValue = function(value) {
		if ((this.bsa > 0) && (value > 0)) {
			if (this.male) return ((value - (7.3 + 15.5 * Math.pow(this.bsa, 0.5))) / 4.0); 
			else return ((value - (2.0 + 17.8* Math.pow(this.bsa, 0.5))) / 3.5); 
		} else return -100;
	}

	this.errorCondition.push((weight <= 0) || (height <= 0))
	this.errorString.push(window.lang.convert("Weight and height are needed"));
	this.errorCondition.push(value <= 0)
	this.errorString.push(window.lang.convert(this.paramNameLong) + " " + window.lang.convert("has to be greater than 0"));

}
grothoffAscendens.prototype = new LMSClass();